@@ -16,15 +16,18 @@
     var service = {
       getTopology: getTopology,
       getAlarms: getAlarms,
+      getHistoryAlarms: getHistoryAlarms,
       getRca: getRca,
-      getTemplates: getTemplates
+      getTemplates: getTemplates,
+      deleteTemplate: deleteTemplate,
+      addTemplate: addTemplate
     };
 
     return service;
 
     ///////////
     // Topology
-    '/static/dashboard/project/topology/graph.sample.json'
+    ///////////
 
     function getTopology(graph_type, config,admin) {
       config = config || {};
@@ -43,33 +46,53 @@
           });
     }
 
-    function getAlarms(vitrage_id,adminState) {
-      if (vitrage_id == undefined){
-        vitrage_id = 'all';
-      }
-      var url = '/api/vitrage/alarm/' + vitrage_id;
-      if (adminState) {
-        url += '/true';
-      }else {
-        url += '/false';
-      }
-      return apiService.get(url)
-        .error(function() {
+    function getAlarms(config) {
+      config = config || {};
+      var url = '/api/vitrage/alarm/';
+
+      return apiService.get(url, config)
+        .catch(function() {
           toastService.add('error', gettext('Unable to fetch the Vitrage Alarms service.'));
         });
+    }
+
+    function getHistoryAlarms(config) {
+      config = config || {};
+
+      var url = '/api/vitrage/history/';
+      return apiService.get(url, config)
+        .catch(function() {
+          toastService.add('error', gettext('Unable to fetch the Vitrage' +
+            ' Alarms History service.'));
+        });
 
     }
 
     function getRca(alarm_id,adminState) {
       return apiService.get('/api/vitrage/rca/'+alarm_id+"/"+adminState)
-          .error(function () {
+          .catch(function () {
             toastService.add('error', gettext('Unable to fetch the Vitrage RCA service.'));
           });
     }
 
     function getTemplates(template_id) {
       return apiService.get('/api/vitrage/template/'+template_id)
-          .error(function () {
+          .catch(function () {
+            toastService.add('error', gettext('Unable to fetch the Vitrage Templates service.'));
+          });
+    }
+
+    function deleteTemplate(template_id) {
+      return apiService.delete('/api/vitrage/template/'+template_id)
+          .catch(function () {
+            toastService.add('error', gettext('Unable to fetch the Vitrage Templates service.'));
+          });
+    }
+
+    function addTemplate(template, type) {
+      var temp = { 'template' : template, 'type': type }
+      return apiService.post('/api/vitrage/template/default/', temp)
+          .catch(function () {
             toastService.add('error', gettext('Unable to fetch the Vitrage Templates service.'));
           });
     }
